@@ -29,7 +29,8 @@ fit_MRMC_test<- function(
                       war = floor(ite/5),
                       ite = 10000,
                       dig = 3,
-                      see = 1234569){
+                      see = 1234569,
+                      Null.Hypothesis=FALSE){
 
 
   if ( is.null(dataList$m)||is.null(dataList$q)||is.null(dataList$c)) {
@@ -44,7 +45,7 @@ fit_MRMC_test<- function(
   # scr <- "Model_Hiera.stan";
   # source("Data_Hiera.R");
 
-
+if(Null.Hypothesis==FALSE){
   if(PreciseLogLikelihood == FALSE  ){
     # scr <- "Model_Hiera.stan";
   scr <- system.file("extdata", "Model_Hiera.stan", package="BayesianFROC")
@@ -57,6 +58,11 @@ fit_MRMC_test<- function(
     } else{
       print("PreciseLogLikelihood is allowed only two choice; TRUE or FALSE.")
     }}
+}#Null.Hypothesis
+
+  if(Null.Hypothesis==TRUE){   scr <- system.file("extdata", "null_hier.stan", package="BayesianFROC")
+}
+
 
   data <-metadata_to_fit_MRMC(dataList)
 
@@ -75,6 +81,7 @@ fit_MRMC_test<- function(
 
 
   if (summary==FALSE)message("\n* Now, the Hamiltonian Monte Carlo simulation is running...")
+  if (summary==FALSE)message(crayon::silver( "\n* To print the procedure, set  summary = TRUE. "))
 
 
   rstan_options(auto_write = TRUE)
@@ -132,7 +139,7 @@ fit_MRMC_test<- function(
 
     if(summary==TRUE) {
           # message("---------- Useage of the return value-------------------------  \n")
-          message(crayon::silver( "\n * Using this return value which is S4 class generated by rstan::stan and another function in this package, you can draw FROC and AFROC curves.   \n"))
+          message(crayon::silver( "\n * Using the return value which is S4 class generated by rstan::stan, you can draw FROC and AFROC curves.   \n"))
           message(crayon::silver( "\n * Using this return value, you can apply functions in the package rstan, e.g., rstan::traceplot().   \n"))
           # message("\n-----------------------------------------  \n")
           # message(" \n--------------------------------------------------  \n")
